%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%

function [tfr,t,f] = dwv(x,t,fs);
%DWV	Unitary Wigner-Ville time-frequency distribution.
%       Uses the "interlaced" signal.
%	[TFR,T,F]=DWV(X,T,FS) computes the Wigner-Ville distribution
%	of a discrete-time signal X, 
% 
%	X     : signal if auto-WV, or [X1,X2] if cross-WV.
%	T     : time instant(s)          (default : 1:length(X)).
%	FS    : sampling frequency       (default : 1).
%	TFR   : time-frequency representation.
%	F     : vector of normalized frequencies.

if (nargin == 0),
 error('At least one parameter required');
end;

[xrow,xcol] = size(x);
N=xrow;

if (nargin == 1),
  t=1:xrow; fs=1; trace=0;
elseif (nargin == 2),
  fs=1; trace=0;
elseif (nargin ==3),
  trace=0;
end;

[trow,tcol] = size(t);
if (xcol==0)|(xcol>2),
  error('X must have one or two columns');
elseif (trow~=1),
  error('T must only have one row'); 
elseif (2^nextpow2(N)~=N),
  error('N must be a power of two');
end; 

%% create the interlaced signal and corresponding time vector
N2=2*N;
x3=zeros(N2,1);
x3(1:2:N2-1)=x;
x3(2:2:N2)=x;

t3=2*t-1;

tfr=lacf(x3,t3);
tfr= fft(tfr)/fs; 

if (xcol==1), tfr=real(tfr); end ;

if (nargout==3),
 f=fs*(0:N2-1)'/N2;
end;

