%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%

%% generate a GW chirp and search with BCC

clear;

snr=20;

%% -- init
debug=0;            % save: yes=0, no=1

% -- signal
N=1024; 
b=16;
Nr1=65;
Nr2=57;
ml=128;
mu=N-ml;
shift_flag=0;

%% -- calibrate search params
fs=2048; % Hz
deltaf=fs/(2*N);
deltat=b/fs;
dotF=Nr1*deltaf/deltat;
ddotF=Nr2*deltaf/deltat^2;

%% -- generate noise and add
n=randn(N,1);
[p,ifl]=randchirp(N,b,Nr1,1,Nr2,ml,mu,shift_flag);
p0=rand*2*pi;
s=cos(p+p0);
x=sqrt(2/N)*snr*real(s)+n;
%x=real(s);

%% -- compute TFR
w=dwv(x);
w=w(1:N,:);

%% -- search params
b=2;
Nr1=9;
Nr2=3;

%% -- apply BCC
[l,m_cc]=dp_bcc(w,b,Nr1,1,Nr2);

%% -- make plots
t=1:b:N+1;
plot(ifl,";GW chirp;");
hold on;
plot(t,m_cc/2/N,";best CC;");
hold off
grid("on");
xlabel("time");
ylabel("frequency");
axis([1 N 0 0.5]);

if (debug==0)
  save -mat-binary figure0c.mat x s w m_cc ifl N b snr
end;
