%%
%% Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
%%
%% This program may be freely copied under the terms of the 
%% GNU General Public License (GPL), version 2, or at your 
%% option any later version.
%%

%% this is a demonstration
%% generate a GW chirp and search with BCC

clear;

snr=10;

%% -- define signal

%% case 1: figure 0
%% N=1024; 
%% fs=2048; % Hz
%% fl=96;   % Hz

%% case 2: figure 1
N=256; 
fs=1024; % Hz
fl=96;   % Hz

[s,ifl,difl,ddifl,cm]=gwchirp(N,fl/fs);

fisco=205*(20*0.43/cm)/fs;

%% -- generate noise and add
x=randn(N,1);
x=x+sqrt(2/N)*snr*real(s);
%x=real(s);

%% -- compute TFR
w=dwv(x);
w=w(1:N,:);

%% -- paramater search

%% case 1 : figure 0
%% b=8;
%% Ns1=32;
%% Ns2=14;

%% case 2 : figure 1
b=8;
Ns1=30;
Ns2=20;

%% -- calibrate search params
deltaf=fs/(2*N);
deltat=b/fs;
dotF=Ns1*deltaf/deltat;
ddotF=Ns2*deltaf/deltat^2;
t1=max(find(fs^2*difl<=dotF));
t2=max(find(fs^3*ddifl<=ddotF));

%% -- apply BCC
[l,m_cc]=dp_bcc(w,b,Ns1,1,Ns2);

%% -- plot results
t=(1:b:N+1)';
plot(ifl,";GW chirp;");
hold on;
plot(t,m_cc/2/N,";best CC;");
plot([t1 t1],[0 0.5],";limit regul. 1st;");
plot([t2 t2],[0 0.5],";limit regul. 2nd;");
plot([1 N],[fisco fisco],";ISCO;");
hold off
grid("on");
xlabel("time");
ylabel("frequency");
axis([1 N 0 0.5]);
