// lacf.cc -- compute the local autocorrelation function.

// To use this file, your version of Octave must support dynamic
// linking.  To find out if it does, type the command
//
//   x = octave_config_info; x.DEFS
//
// at the Octave prompt.  Support for dynamic linking is included if
// the output contains the string -DWITH_DYNAMIC_LINKING=1.
//
// To compile this file, type the command
//
// mkoctfile --verbose lacf.cc
//
// at the shell prompt.  The script mkoctfile should have been
// installed along with Octave.  Running it will create a file called
// lacf.oct that can be loaded by Octave.
//
// Enter:
//
// help lacf
//
// at the Octave prompt to have a description of how lacf should be used.  
// 
// This file may be used under the terms defined by the GNU 
// General Public License [write to the Free Software Foundation, 
// 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA]
//
// WITHOUT ANY WARRANTY; without even the implied warranty 
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
//
// Copyright (C) 2005 Eric Chassande-Mottin, CNRS (France)
//

#include <octave/config.h>

#include <iostream>
#include <sstream>
using namespace std;
#include <string>

#include <octave/defun-dld.h>
#include <octave/error.h>
#include <octave/oct-obj.h>
#include <octave/pager.h>
#include <octave/symtab.h>
#include <octave/variables.h>

static inline int
getmin ( int x, int y)
{
  return x < y ? x : y;
}

DEFUN_DLD (lacf, args, ,
  "LACF: compute the local autocorrelation function.\n")
{
  octave_value_list retval;
  
  /*----------- get input parameters ----------------*/
  int nargin = args.length ();
  
  if (nargin < 2)
    {
      // print_usage("lacf");
      error("Usage: out = lacf(in,t)");
      return retval;
    }

  /* get the data */
  ComplexColumnVector in(args(0).complex_vector_value());

  /* get the time vector */
  ColumnVector t(args(1).vector_value());
  
  /* create output data */
  int N=in.length();
  int tcol=t.length();
  ComplexMatrix out(N,tcol,0);

  /* compute lacf */
  int taumax;
  for (int n=0 ; n<tcol ; n++)
    {    
      int ti= (int) t(n)-1; 
      taumax=getmin(ti,N-1-ti);
      for (int tau=-taumax; tau<=taumax ; tau++)
	out((N+tau)%N,n)=in(ti+tau)*conj(in(ti-tau));
    }
  
  retval(0)=out;
  
  return retval;
}





